@@ -1,23 +1,24 @@
 import uuid
+from contextlib import asynccontextmanager
 from typing import Any, Optional, Tuple, Union
 
-try:
-    from contextlib import asynccontextmanager
-except ImportError:  # python 3.6
-    from async_generator import asynccontextmanager
-
 
 class LockedException(Exception):
     pass
 
 
 class Backend:
+    name: str = ""
+
     def __init__(self, *args, **kwargs):
         ...
 
     async def init(self):
         ...
 
+    def is_init(self):
+        ...
+
     async def close(self):
         ...
 
@@ -38,6 +39,9 @@ class Backend:
     async def get_many(self, *keys: str) -> Tuple[Any]:
         ...
 
+    async def exists(self, key) -> bool:
+        ...
+
     async def keys_match(self, pattern: str):
         ...
 
@@ -62,9 +66,6 @@ class Backend:
         """
         ...
 
-    async def get_counters(self, template):
-        ...
-
     async def ping(self, message: Optional[bytes] = None) -> str:
         ...
 
@@ -98,10 +99,16 @@ class Backend:
 
 
 class ProxyBackend(Backend):
-    def __init__(self, target=None):
+    def __init__(self, target=None, name=None):
+        if name:
+            self.name = name
         self._target = target
         super().__init__()
 
+    @property
+    def is_init(self):
+        return self._target.is_init
+
     def set(self, key: str, value: Any, expire: Union[None, float, int] = None, exist: Optional[bool] = None) -> bool:
         return self._target.set(key, value, expire=expire, exist=exist)
 
@@ -117,6 +124,9 @@ class ProxyBackend(Backend):
     def get_many(self, *keys: str) -> Tuple[Any]:
         return self._target.get_many(keys)
 
+    def exists(self, key):
+        return self._target.exists(key)
+
     def incr(self, key: str) -> int:
         return self._target.incr(key)
 
