@@ -38,12 +38,12 @@ def hit(
         @wraps(func)
         async def _wrap(*args, _from_cache: CacheDetect = context_cache_detect, **kwargs):
             _cache_key = get_cache_key(func, _key_template, args, kwargs)
-            result = await backend.get(_cache_key, default=_empty)
-            hits = await backend.incr(_cache_key + ":counter")
+            result, hits = await asyncio.gather(
+                backend.get(_cache_key, default=_empty),
+                backend.incr(_cache_key + ":counter"),
+            )
             if result is not _empty and hits and hits <= cache_hits:
-                _from_cache.set(
-                    _cache_key, ttl=ttl, cache_hits=cache_hits, name="hit", backend=backend.__class__.__name__
-                )
+                _from_cache._set(_cache_key, ttl=ttl, cache_hits=cache_hits, name="hit", backend=backend.name)
                 if update_before is not None and cache_hits - hits <= update_before:
                     asyncio.create_task(_get_and_save(func, args, kwargs, backend, _cache_key, ttl, store))
                 return result
