@@ -14,11 +14,11 @@ pytestmark = pytest.mark.asyncio
 @pytest.fixture(name="cache")
 async def _cache():
     if os.environ.get("USE_REDIS"):
-        redis = Redis("redis://", hash_key=None, count_stat=True)
+        redis = Redis("redis://", hash_key=None)
         await redis.init()
         await redis.clear()
         return redis
-    return Memory(count_stat=True)
+    return Memory()
 
 
 async def test_set_get(cache):
@@ -61,6 +61,12 @@ async def test_ping(cache):
     assert await cache.ping() == b"PONG"
 
 
+async def test_exists(cache):
+    assert not await cache.exists("not")
+    await cache.set("yes", "1")
+    assert await cache.exists("yes")
+
+
 async def test_expire(cache):
     await cache.set("key", b"value", expire=0.01)
     assert await cache.get("key") == b"value"
@@ -80,8 +86,11 @@ async def test_get_set_expire(cache):
     ("method", "args", "defaults"),
     (
         ("get", ("key",), {"default": None}),
+        ("get_row", ("key",), None),
         ("set", ("key", "value"), {"exist": None, "expire": None}),
+        ("set_row", ("key", "value"), None),
         ("incr", ("key",), None),
+        ("exists", ("key",), None),
         ("delete", ("key",), None),
         ("expire", ("key", 10), None),
         ("ping", (), None),
@@ -130,17 +139,6 @@ async def test_get_size(cache: Backend):
     )  # 106 - ordered dict,  66 redis
 
 
-async def test_get_count_stat(cache: Backend):
-    from cashews.key import register_template
-
-    register_template(test_get_count_stat, "my:{val}")
-    await cache.set("my:hit", b"10")
-    await cache.get("my:hit")
-    await cache.get("my:miss")
-
-    assert await cache.get_counters("my:*") == {"hit": 1, "set": 1, "miss": 1}
-
-
 async def test_lru():
     cache = Memory(size=10)
     # full cache
