@@ -16,8 +16,8 @@ class CustomError(Exception):
     pass
 
 
-@pytest.fixture()
-async def backend():
+@pytest.fixture(name="backend")
+async def _backend():
     if REDIS_TESTS:
         redis = Redis("redis://", hash_key=None)
         await redis.init()
@@ -29,7 +29,7 @@ async def backend():
 
 
 async def test_fail_cache_simple(backend):
-    @decorators.fail(backend, ttl=EXPIRE, exceptions=CustomError, key="fail")
+    @decorators.failover(backend, ttl=EXPIRE, exceptions=CustomError, key="fail")
     async def func(fail=False):
         if fail:
             raise CustomError()
@@ -44,7 +44,7 @@ async def test_fail_cache_simple(backend):
 
 
 async def test_circuit_breaker_simple(backend):
-    @decorators.circuit_breaker(backend, ttl=EXPIRE * 10, errors_rate=5, period=1, key="test")
+    @decorators.circuit_breaker(backend, ttl=EXPIRE * 10, min_calls=10, errors_rate=5, period=1, key="test")
     async def func(fail=False):
         if fail:
             raise CustomError()
@@ -64,6 +64,40 @@ async def test_circuit_breaker_simple(backend):
         await func(fail=False)
 
 
+async def test_circuit_breaker_half_open(backend):
+    @decorators.circuit_breaker(
+        backend, ttl=EXPIRE, half_open_ttl=0.1, errors_rate=1, min_calls=0, period=1, key="test"
+    )
+    async def func(fail=False):
+        if fail:
+            raise CustomError()
+        return b"ok"
+
+    with pytest.raises(CustomError):
+        await func(fail=True)
+
+    with pytest.raises(decorators.CircuitBreakerOpen):
+        await func(fail=True)
+
+    await asyncio.sleep(EXPIRE)
+
+    errors = 0
+    success = 0
+    for _ in range(100):
+        try:
+            await func(fail=False)
+        except decorators.CircuitBreakerOpen:
+            errors += 1
+        else:
+            success += 1
+    assert success > 0
+    assert errors > 0
+    assert success + errors == 100
+
+    await asyncio.sleep(0.1)
+    assert await func() == b"ok"
+
+
 async def test_cache_simple(backend):
     @decorators.cache(backend, ttl=EXPIRE, key="key")
     async def func(resp=b"ok"):
@@ -94,7 +128,7 @@ async def test_cache_simple_none(backend):
 
 
 async def test_cache_simple_key(backend):
-    @decorators.cache(backend, ttl=EXPIRE, key="key:{some}")
+    @decorators.cache(backend, ttl=1, key="key:{some}")
     async def func(resp=b"ok", some="err"):
         return resp
 
@@ -282,12 +316,12 @@ async def test_cache_detect_simple(backend):
 
     cache_detect = decorators.CacheDetect()
     assert await func(_from_cache=cache_detect) == b"ok"
-    assert cache_detect.get() == {}
+    assert cache_detect.keys == {}
 
     await asyncio.sleep(0)
     assert await func(b"notok", _from_cache=cache_detect) == b"ok"
-    assert len(cache_detect.get()) == 1
-    assert list(cache_detect.get().keys()) == [
+    assert len(cache_detect.keys) == 1
+    assert list(cache_detect.keys.keys()) == [
         "key",
     ]
 
@@ -297,20 +331,21 @@ async def test_context_cache_detect_simple(backend):
     async def func(resp=b"ok"):
         return resp
 
-    decorators.context_cache_detect.start()
-    assert await func() == b"ok"
-    assert decorators.context_cache_detect.get() == {}
+    with decorators.context_cache_detect as detector:
+        assert await func() == b"ok"
+        assert detector.keys == {}
 
-    await asyncio.sleep(0)
-    assert await func(b"notok") == b"ok"
-    assert len(decorators.context_cache_detect.get()) == 1
-    assert list(decorators.context_cache_detect.get().keys()) == [
-        "key",
-    ]
+        await asyncio.sleep(0)
+        assert await func(b"notok") == b"ok"
+        assert list(detector.keys.keys()) == [
+            "key",
+        ]
 
-    await asyncio.sleep(EXPIRE * 1.1)
-    assert await func(b"notok") == b"notok"
-    assert len(decorators.context_cache_detect.get()) == 1
+        await asyncio.sleep(EXPIRE * 1.1)
+        assert await func(b"notok") == b"notok"
+        assert len(detector.keys) == 1
+
+    assert decorators.context_cache_detect._levels == {}
 
 
 async def test_context_cache_detect_deep(backend):
@@ -325,20 +360,21 @@ async def test_context_cache_detect_deep(backend):
     async def func():
         return await asyncio.gather(func1(), func2())
 
-    decorators.context_cache_detect.start()
-    await func()
-    assert decorators.context_cache_detect.get() == {}
+    with decorators.context_cache_detect as detector:
+        await func()
+        assert detector.keys == {}
 
-    await asyncio.sleep(0)
-    await func()
+        await asyncio.sleep(0)
+        await func()
 
-    assert len(decorators.context_cache_detect.get()) == 2
-    assert "key1" in decorators.context_cache_detect.get()
-    assert "key2" in decorators.context_cache_detect.get()
+        assert len(detector.keys) == 2
+        assert "key1" in detector.keys
+        assert "key2" in detector.keys
+    assert decorators.context_cache_detect._levels == {}
 
 
 async def test_context_cache_detect_context(backend):
-    assert decorators.context_cache_detect.get() is None
+    assert decorators.context_cache_detect._get() is None
 
     @decorators.cache(backend, ttl=EXPIRE, key="key1")
     async def func1():
@@ -349,18 +385,24 @@ async def test_context_cache_detect_context(backend):
         return 2
 
     async def func(*funcs):
-        decorators.context_cache_detect.start()
-        res = await asyncio.gather(*funcs)
-        return len(decorators.context_cache_detect.get())
+        with decorators.context_cache_detect as detector:
+            await asyncio.gather(*funcs)
+            return len(detector.keys)
 
-    await backend.set(f"key1", "test")
-    await backend.set(f"key2", "test")
+    await backend.set("key1", "test")
+    await backend.set("key2", "test")
     assert await func1() == "test"
     assert await func2() == "test"
 
-    assert decorators.context_cache_detect.get() is None
+    assert decorators.context_cache_detect._get() is None
 
-    assert await asyncio.create_task(func(func1())) == 1
-    assert await asyncio.create_task(func(func1(), func2())) == 2
-    assert await asyncio.create_task(func(func2(), func2())) == 1
-    assert decorators.context_cache_detect.get() is None  # ! It should be 3 but for now  it is ok, have no user case
+    with decorators.context_cache_detect as detector:
+        assert await asyncio.create_task(func(func1())) == 1
+        assert await asyncio.create_task(func(func1(), func2())) == 2
+        assert await asyncio.create_task(func(func2())) == 1
+        assert await asyncio.create_task(func(func2(), func2())) == 1
+
+        assert len(detector.keys) == 2
+
+    assert decorators.context_cache_detect._get() is None
+    assert decorators.context_cache_detect._levels == {}
