@@ -2,7 +2,7 @@ import asyncio
 import os
 
 import pytest
-from cashews.backends.client_side import BcastClientSide, UpdateChannelClientSide
+from cashews.backends.client_side import BcastClientSide
 from cashews.backends.memory import Memory
 
 pytestmark = pytest.mark.asyncio
@@ -81,45 +81,28 @@ async def test_rewrite_bcast(create_cache):
 
 
 @pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
-async def test_set_get_custom_chan(create_cache):
-    cachef_local = Memory()
-    cachef = await create_cache(UpdateChannelClientSide, cachef_local)
-    caches_local = Memory()
-    caches = await create_cache(UpdateChannelClientSide, caches_local)
-    caches._pool_or_conn.get = None
+async def test_simple_cmd_bcast(create_cache):
+    local = Memory()
+    cache = await create_cache(BcastClientSide, local)
 
-    await cachef.set("key", b"value", expire=0.1)
-    assert await cachef_local.get("key") == b"value"
-    await asyncio.sleep(0.05)  #  wait cache update
-    assert await cachef_local.get("key") == b"value"
-    assert await caches_local.get("key") == b"value"
-    assert await caches_local.get_expire("key") == 0
-    assert await cachef.get("key") == b"value"
-    assert await caches.get("key") == b"value"
-    assert await cachef_local.get("key") == b"value"
-    await asyncio.sleep(0.2)
+    await cache.set("key:1", "test", 1)
+    await asyncio.sleep(0.1)  # skip init signal about invalidation
+    assert await cache.get("key:1") == "test"
 
-    assert await cachef_local.get("key") is None
-    assert await caches_local.get("key") is None
+    await cache.incr("key:2")
+    assert await cache.get("key:2") == 1
+    await cache.delete("key:2")
+    assert await cache.get("key:2") is None
+    assert await local.get("key:2") is None
 
-    assert await caches.get("key") is None
+    assert await cache.get("key:1") == "test"
+    assert await local.get("key:1") == "test"
+    await cache.expire("key:1", 3)
+    assert await cache.get_expire("key:1") > 0
+    assert await local.get_expire("key:1") > 0
 
-
-@pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
-async def test_set_get_del_custom_chan_serialize(create_cache):
-    cachef_local = Memory()
-    cachef = await create_cache(UpdateChannelClientSide, cachef_local)
-    caches_local = Memory()
-    caches = await create_cache(UpdateChannelClientSide, caches_local)
-    value = {"my": None}
-    await cachef.set("key", value)
-    await asyncio.sleep(0.05)  # wait cache update
-    assert await cachef_local.get("key") == value
-    assert await caches_local.get("key") == value
-    assert await caches.get("key") == value
-
-    await cachef.delete("key")
-    assert await cachef_local.get("key") is None
-
-    await asyncio.sleep(0.05)  # wait cache update
-    assert await caches_local.get("key") is None
+    assert await cache.delete_match("key:*")
+    assert await cache.get("key:1") is None
+    assert await local.get("key:1") is None
+    await cache.clear()
+    cache.close()
