@@ -61,7 +61,7 @@ async def test_invalidate_decor(cache: Cache):
 
 
 async def test_invalidate_decor_complicate(cache: Cache):
-    @cache(ttl=1, key="arg-{arg}:{key}:{flag}:{name}")
+    @cache(ttl=1, key="arg-{arg}:{key}:{flag}")
     async def func(arg, key=b"test", flag=True, **kwargs):
         return random.random()
 
