@@ -1,44 +1,51 @@
 import asyncio
-import random
-from unittest.mock import Mock, patch
+from unittest.mock import Mock
 
 import pytest
-from cashews.backends.interface import Backend
 from cashews.backends.memory import Memory
+from cashews.disable_control import ControlMixin
 from cashews.helpers import add_prefix
-from cashews.wrapper import Cache
+from cashews.key import get_templates_for_func
+from cashews.wrapper import Cache, _auto_init
+
+pytestmark = pytest.mark.asyncio
 
 
 @pytest.fixture(name="target")
 def _target():
-    return Mock(wraps=Memory())
+    class New(ControlMixin, Memory):
+        pass
+
+    return Mock(wraps=New())
 
 
 @pytest.fixture(name="cache")
 def __cache(target):
     _cache = Cache()
-    _cache._target = target
+    _cache._add_backend(Memory)
+    _cache._backends[""] = (target, _cache._backends[""][1])
     return _cache
 
 
-def test_setup(cache):
-    backend = Mock()
-    cache._target = None
-    with patch("cashews.wrapper.Memory", backend):
-        cache.setup("mem://localhost?test=1")
-    backend.assert_called_with(test=1)
-
-
-@pytest.mark.asyncio
 async def test_init_disable(cache):
-    backend = Mock(wraps=Backend())
-    with patch("cashews.wrapper.Memory", Mock(return_value=backend)):
-        await cache.init("mem://localhost?disable=1")
-    backend.init.assert_not_called()
+    await cache.init("mem://localhost?disable=1")
     assert cache.is_disable()
 
 
-@pytest.mark.asyncio
+async def test_prefix(cache):
+    await cache.init("mem://localhost")
+    await cache.init("://", prefix="-")
+    assert not cache.is_disable()
+    assert cache.is_disable(prefix="-")
+
+    await cache.set("key", "value")
+    await cache.set("-:key", "-value")
+
+    assert await cache.get("key") == "value"
+    assert await cache.get("-:key") == None
+    assert await cache.get("-:key", default="def") == "def"
+
+
 async def test_disable_cmd(cache):
     await cache.init("mem://localhost")
     cache.disable("incr")
@@ -51,15 +58,14 @@ async def test_disable_cmd(cache):
     assert await cache.get("test") == 11
 
 
-@pytest.mark.asyncio
 async def test_disable_ctz(cache):
     await cache.init("mem://localhost")
-    cache.enable("cmds")
+    cache.enable()
 
     async def test():
         await cache.set("test", "1")
         assert await cache.get("test") == "1"
-        cache.disable("cmds")
+        cache.disable("set")
         await cache.set("test", "2")
 
     await asyncio.create_task(test())
@@ -68,9 +74,8 @@ async def test_disable_ctz(cache):
     assert await cache.get("test") == "3"
 
 
-@pytest.mark.asyncio
 async def test_disable_decorators(cache: Cache, target):
-    cache.disable("decorators")
+    cache.disable()
     data = (i for i in range(10))
 
     @cache(ttl=1)
@@ -90,25 +95,31 @@ async def test_disable_decorators(cache: Cache, target):
     target.get.assert_not_called()
     target.set.assert_not_called()
 
-    cache.enable("decorators")
+    cache.enable()
     assert await func() == 2
-    target.get.assert_called()
-    target.set.assert_called()
     assert await func() == 2
 
 
-@pytest.mark.asyncio
-async def test_disable_decorators_get(cache: Cache, target):
+async def test_disable_decorators_get(cache: Cache):
     data = (i for i in range(10))
+    await cache.init("mem://localhost")
 
     @cache(ttl=1)
     async def func():
         return next(data)
 
+    assert cache.is_enable()
+    assert cache.is_enable("set", prefix="cache")
+    assert cache.is_enable("get", prefix="cache")
+    assert cache.is_enable("set", prefix="")
     assert await func() == 0
     assert await func() == 0
 
     cache.disable("get")
+
+    assert not cache.is_enable("get")
+    assert cache.is_enable("set")
+
     assert await func() == 1
     assert await func() == 2
 
@@ -116,8 +127,7 @@ async def test_disable_decorators_get(cache: Cache, target):
     assert await func() == 2
 
 
-@pytest.mark.asyncio
-async def test_disable_decorators_set(cache: Cache, target):
+async def test_disable_decorators_set(cache: Cache):
     data = (i for i in range(10))
     cache.disable("set")
 
@@ -126,7 +136,6 @@ async def test_disable_decorators_set(cache: Cache, target):
         return next(data)
 
     assert await func() == 0
-    target.get.assert_called()
     assert await func() == 1
 
     cache.enable("set")
@@ -134,24 +143,21 @@ async def test_disable_decorators_set(cache: Cache, target):
     assert await func() == 2
 
 
-@pytest.mark.asyncio
 async def test_init(cache):
-    backend = Mock(wraps=Backend())
-    with patch("cashews.wrapper.Memory", Mock(return_value=backend)):
-        await cache.init("mem://localhost")
-    backend.init.assert_called_once()
+    await cache.init("mem://localhost")
     assert cache.is_enable()
 
 
-@pytest.mark.asyncio
-async def test_auto_init(cache, target):
-    await cache.ping()
-    target.init.assert_called_once()
+async def test_auto_init(cache):
+    target = Memory()
+    cache._backends[""] = target, (_auto_init,)
+    assert not target.is_init
+    assert b"PONG" == await cache.ping()
+    assert target.is_init
 
 
-@pytest.mark.asyncio
 async def test_add_prefix(cache: Cache, target):
-    cache.middlewares = (add_prefix("prefix!"),)
+    cache._backends[""] = cache._backends[""][0], (add_prefix("prefix!"),)
 
     await cache.get(key="key")
     target.get.assert_called_once_with(key="prefix!key", default=None)
@@ -161,24 +167,21 @@ async def test_add_prefix(cache: Cache, target):
         key="prefix!key", value="value", exist=None, expire=None,
     )
     await cache.ping()
-    target.ping.assert_called_once_with(message=None)
+    target.ping.assert_called_once_with(message=b"PING")
 
 
-@pytest.mark.asyncio
 async def test_add_prefix_get_many(cache: Cache, target):
-    cache.middlewares = (add_prefix("prefix!"),)
+    cache._backends[""] = cache._backends[""][0], (add_prefix("prefix!"),)
     await cache.get_many("key")
     target.get_many.assert_called_once_with("prefix!key")
 
 
-@pytest.mark.asyncio
 async def test_add_prefix_delete_match(cache: Cache, target):
-    cache.middlewares = (add_prefix("prefix!"),)
+    cache._backends[""] = cache._backends[""][0], (add_prefix("prefix!"),)
     await cache.delete_match("key")
     target.delete_match.assert_called_once_with(pattern="prefix!key")
 
 
-@pytest.mark.asyncio
 async def test_smoke_cmds(cache: Cache, target):
     await cache.set(key="key", value={"any": True}, expire=60, exist=None)
     target.set.assert_called_once_with(key="key", value={"any": True}, expire=60, exist=None)
@@ -216,16 +219,73 @@ async def test_smoke_cmds(cache: Cache, target):
     await cache.unlock("key", "value")  # -> bool
     target.unlock.assert_called_once_with(key="key", value="value")
 
+    await cache.exists("key")
+    target.exists.assert_called_once_with(key="key")
+
 
 async def test_disable_cache_on_fail_return(cache: Cache):
-    @cache(ttl=0.05, key="cache")
-    @cache.fail(ttl=1, key="fail")
+    assert await cache.get("key") is None
+
+    @cache(ttl=1, key="key", upper=True)
+    @cache.failover(ttl=1, key="fail", prefix="")
     async def func(fail=False):
         if fail:
             raise Exception()
-        return random.randint(0, 100)
+        return "1"
 
-    first = await func()  # cache by fail and siple cache
-    await asyncio.sleep(0.1)  # expire simple cache
-    assert await func(fail=True) == first  # return from fail cache but simple cache should be skipped
-    assert await func() != first
+    await cache.set("fail", "test_fail")
+
+    assert await func(fail=True) == "test_fail"  # return from fail cache but simple cache should be skipped
+    assert await cache.get("key") is None
+
+    await cache.delete("fail")
+    await cache.set("key", "val")
+    assert await func() == "val"
+
+
+async def test_disable_cache_on_fail_return_2(cache: Cache):
+    assert await cache.get("key") is None
+
+    @cache.failover(ttl=1, key="fail", prefix="")
+    @cache(ttl=1, key="key")
+    async def func(fail=False):
+        if fail:
+            raise Exception()
+        return "1"
+
+    await cache.set("fail", "test_fail")
+
+    assert await func(fail=True) == "test_fail"  # return from fail cache but simple cache should be skipped
+    assert await cache.get("key") is None
+
+    await cache.delete("fail")
+    assert await cache.get("fail") is None
+    await cache.set("key", "val")
+    assert await func() == "val"
+    assert await cache.get("fail") is None
+
+
+async def test_multilayer_cache(cache: Cache):
+    # If results from key2, key1 must not be set
+
+    @cache(ttl=1, key="key1", upper=True)
+    @cache(ttl=1, key="key2")
+    async def func():
+        return 1
+
+    await cache.set("key2", "test2")
+
+    assert await func() == "test2"
+    assert await cache.get("key1") is None
+
+    await cache.set("key1", "test1")
+    assert await func() == "test1"
+    assert await cache.get("key2") == "test2"
+
+
+async def test_cache_decor_register(cache: Cache):
+    @cache(ttl=1, key="key:{val}", prefix="test")
+    async def my_func(val=1):
+        return val
+
+    assert next(get_templates_for_func(my_func)) == "test:key:{val}"
